import cv2

# マスク比率をコマンドライン引数から取得（追加）
import sys
mask_scale = 0.55
if len(sys.argv) == 2 and sys.argv[1].isdecimal():
  parameter = int(sys.argv[1])
  if parameter >= 10 and parameter <= 99:
    mask_scale = float(parameter) / 100

# 元写真とマスク画像を読み込み
img_original = cv2.imread('original_photo.jpg')
img_mask = cv2.imread('mask.png', cv2.IMREAD_UNCHANGED)

# 顔を認識
cascade = cv2.CascadeClassifier('haarcascade_frontalface_default.xml')
img_original_gray = cv2.cvtColor(img_original, cv2.COLOR_BGR2GRAY)
faces = cascade.detectMultiScale(img_original_gray, scaleFactor=1.5)

# それぞれの顔について
for (f_x, f_y, f_w, f_h) in faces:

  # 顔領域を長方形で表示
  cv2.rectangle(img_original, (f_x, f_y), (f_x + f_w, f_y + f_h), (0, 0, 255), thickness=2)

  #マスクの開始位置とサイズを取得（変更）
  m_x = f_x
  m_w = f_w
  m_h = int(f_h * mask_scale)
  m_y = f_y + f_h - m_h

  #マスクを拡大・縮小
  img_mask_scaled = cv2.resize(img_mask, (m_w, m_h))

  # 元写真の上にマスク画像を重ねる
  img_mask_alpha = img_mask_scaled[:, :, 3:] / 255
  img_original[m_y:m_y + m_h, m_x:m_x + m_w] = \
  img_original[m_y:m_y + m_h, m_x:m_x + m_w] * \
  (1 - img_mask_alpha) + img_mask_scaled[:, :, :3] * img_mask_alpha

# 結果の表示
cv2.imshow('put on mask', img_original)

# キーボードが押されるまで待ち、押されたらウインドウを閉じる
cv2.waitKey(0)
cv2.destroyAllWindows()
